==> react-ui-5.0.0.tgz: package/DefinitionList.js <==
/******/ (() => {
    // webpackBootstrap
    /******/ "use strict";
    /******/ // The require scope
    /******/    var e = {};
    /******/
    /************************************************************************/
    /******/ /* webpack/runtime/compat get default export */
    /******/    (() => {
        /******/ // getDefaultExport function for compatibility with non-harmony modules
        /******/ e.n = r => {
            /******/ var t = r && r.__esModule ? 
            /******/ () => r["default"]
            /******/ : () => r
            /******/;
            e.d(t, {
                a: t
            });
            /******/            return t;
            /******/        };
        /******/    })();
    /******/
    /******/ /* webpack/runtime/define property getters */
    /******/    (() => {
        /******/ // define getter functions for harmony exports
        /******/ e.d = (r, t) => {
            /******/ for (var n in t) {
                /******/ if (e.o(t, n) && !e.o(r, n)) {
                    /******/ Object.defineProperty(r, n, {
                        enumerable: true,
                        get: t[n]
                    });
                    /******/                }
                /******/            }
            /******/        };
        /******/    })();
    /******/
    /******/ /* webpack/runtime/hasOwnProperty shorthand */
    /******/    (() => {
        /******/ e.o = (e, r) => Object.prototype.hasOwnProperty.call(e, r)
        /******/;
    })();
    /******/
    /******/ /* webpack/runtime/make namespace object */
    /******/    (() => {
        /******/ // define __esModule on exports
        /******/ e.r = e => {
            /******/ if (typeof Symbol !== "undefined" && Symbol.toStringTag) {
                /******/ Object.defineProperty(e, Symbol.toStringTag, {
                    value: "Module"
                });
                /******/            }
            /******/            Object.defineProperty(e, "__esModule", {
                value: true
            });
            /******/        };
        /******/    })();
    /******/
    /************************************************************************/    var r = {};
    // ESM COMPAT FLAG
        e.r(r);
    // EXPORTS
        e.d(r, {
        Description: () => /* reexport */ v,
        Term: () => /* reexport */ P,
        default: () => /* reexport */ _
    });
    // CONCATENATED MODULE: external "react"
    const t = require("react");
    var n =  e.n(t);
    // CONCATENATED MODULE: external "prop-types"
    const i = require("prop-types");
    var o =  e.n(i);
    // CONCATENATED MODULE: ./src/DefinitionList/DefinitionListContext.tsx
    var a =  (0, t.createContext)({});
    // CONCATENATED MODULE: external "styled-components"
    const l = require("styled-components");
    var c =  e.n(l);
    // CONCATENATED MODULE: external "@splunk/themes"
    const s = require("@splunk/themes");
    // CONCATENATED MODULE: ./src/DefinitionList/DescriptionStyles.ts
    var u = c().dd.withConfig({
        displayName: "DescriptionStyles__Styled",
        componentId: "sc-1jglixb-0"
    })([ "", ";", ";min-height:1.5em;padding-inline-start:", ";margin-inline-start:", ";" ], s.mixins.reset("block"), s.mixins.typography("body", {
        color: "active"
    }), s.variables.spacingSmall, (function(e) {
        var r = e.$termWidth;
        return r;
    }));
    // CONCATENATED MODULE: ./src/DefinitionList/Description.tsx
    function f() {
        return f = Object.assign ? Object.assign.bind() : function(e) {
            for (var r = 1; r < arguments.length; r++) {
                var t = arguments[r];
                for (var n in t) {
                    ({}).hasOwnProperty.call(t, n) && (e[n] = t[n]);
                }
            }
            return e;
        }, f.apply(null, arguments);
    }
    function d(e, r) {
        if (null == e) return {};
        var t, n, i = p(e, r);
        if (Object.getOwnPropertySymbols) {
            var o = Object.getOwnPropertySymbols(e);
            for (n = 0; n < o.length; n++) {
                t = o[n], r.includes(t) || {}.propertyIsEnumerable.call(e, t) && (i[t] = e[t]);
            }
        }
        return i;
    }
    function p(e, r) {
        if (null == e) return {};
        var t = {};
        for (var n in e) {
            if ({}.hasOwnProperty.call(e, n)) {
                if (r.includes(n)) continue;
                t[n] = e[n];
            }
        }
        return t;
    }
    var m = {
        children: o().node.isRequired,
        elementRef: o().oneOfType([ o().func, o().object ])
    };
    /**
 * Container component for a `DefinitionList` description.
 */    function y(e) {
        var r = e.children, i = e.elementRef, o = d(e, [ "children", "elementRef" ]);
        // @docs-props-type DescriptionPropsBase
                var l = (0, t.useContext)(a), c = l.termWidth;
        
        return n().createElement(u, f({
            "data-test": "description",
            ref: i,
            $termWidth: c
        }, o), r);
    }
    y.propTypes = m;
    /* harmony default export */    const v = y;
    // CONCATENATED MODULE: ./src/DefinitionList/DefinitionListStyles.ts
    var h = c().dl.withConfig({
        displayName: "DefinitionListStyles__Styled",
        componentId: "sc-1pqfrgm-0"
    })([ "", ";", ";" ], s.mixins.reset("block"), s.mixins.typography("body"));
    // CONCATENATED MODULE: ./src/DefinitionList/TermStyles.ts
    var b = c().dt.withConfig({
        displayName: "TermStyles__Styled",
        componentId: "sc-1ao97j9-0"
    })([ "", ";", " float:left;overflow:hidden;overflow-x:hidden;white-space:nowrap;word-wrap:normal;", " width:", ";" ], s.mixins.reset("block"), s.mixins.typography("body", {
        color: "muted"
    }), (function(e) {
        var r = e.$separator;
        return r && r !== "none" && (0, l.css)([ "&::after{content:'", "';}" ], " ".concat(r.repeat(100)));
    }), (function(e) {
        var r = e.$termWidth;
        return r;
    }));
    // CONCATENATED MODULE: ./src/DefinitionList/Term.tsx
    function g() {
        return g = Object.assign ? Object.assign.bind() : function(e) {
            for (var r = 1; r < arguments.length; r++) {
                var t = arguments[r];
                for (var n in t) {
                    ({}).hasOwnProperty.call(t, n) && (e[n] = t[n]);
                }
            }
            return e;
        }, g.apply(null, arguments);
    }
    function O(e, r) {
        if (null == e) return {};
        var t, n, i = w(e, r);
        if (Object.getOwnPropertySymbols) {
            var o = Object.getOwnPropertySymbols(e);
            for (n = 0; n < o.length; n++) {
                t = o[n], r.includes(t) || {}.propertyIsEnumerable.call(e, t) && (i[t] = e[t]);
            }
        }
        return i;
    }
    function w(e, r) {
        if (null == e) return {};
        var t = {};
        for (var n in e) {
            if ({}.hasOwnProperty.call(e, n)) {
                if (r.includes(n)) continue;
                t[n] = e[n];
            }
        }
        return t;
    }
    var j = {
        children: o().node.isRequired,
        elementRef: o().oneOfType([ o().func, o().object ])
    };
    /**
 * Container component for a `DefinitionList` term.
 */    function S(e) {
        var r = e.children, i = e.elementRef, o = O(e, [ "children", "elementRef" ]);
        // @docs-props-type TermPropsBase
                var l = (0, t.useContext)(a), c = l.separatorCharacter, s = l.termWidth;
        
        return n().createElement(b, g({
            "data-test": "term",
            ref: i,
            $separator: c,
            $termWidth: s
        }, o), r);
    }
    S.propTypes = j;
    /* harmony default export */    const P = S;
    // CONCATENATED MODULE: ./src/DefinitionList/DefinitionList.tsx
    function x() {
        return x = Object.assign ? Object.assign.bind() : function(e) {
            for (var r = 1; r < arguments.length; r++) {
                var t = arguments[r];
                for (var n in t) {
                    ({}).hasOwnProperty.call(t, n) && (e[n] = t[n]);
                }
            }
            return e;
        }, x.apply(null, arguments);
    }
    function C(e, r) {
        if (null == e) return {};
        var t, n, i = R(e, r);
        if (Object.getOwnPropertySymbols) {
            var o = Object.getOwnPropertySymbols(e);
            for (n = 0; n < o.length; n++) {
                t = o[n], r.includes(t) || {}.propertyIsEnumerable.call(e, t) && (i[t] = e[t]);
            }
        }
        return i;
    }
    function R(e, r) {
        if (null == e) return {};
        var t = {};
        for (var n in e) {
            if ({}.hasOwnProperty.call(e, n)) {
                if (r.includes(n)) continue;
                t[n] = e[n];
            }
        }
        return t;
    }
    var T = {
        children: o().node,
        elementRef: o().oneOfType([ o().func, o().object ]),
        termWidth: o().string,
        separatorCharacter: o().oneOf([ ".", o().string ])
    };
    function W(e) {
        var r = e.children, t = e.elementRef, i = e.termWidth, o = i === void 0 ? "120px" : i, l = e.separatorCharacter, c = C(e, [ "children", "elementRef", "termWidth", "separatorCharacter" ]);
        // @docs-props-type DefinitionListPropsBase
        // eslint-disable-next-line react/jsx-no-constructed-context-values, react-perf/jsx-no-new-object-as-prop
                var s = {
            separatorCharacter: l,
            termWidth: o
        };
        
        return n().createElement(h, x({
            "data-test": "definition-list",
            ref: t
        }, c),  n().createElement(a.Provider, {
            value: s
        }, r));
    }
    W.propTypes = T;
    W.Description = v;
    W.Term = P;
    /* harmony default export */    const _ = W;
    // CONCATENATED MODULE: ./src/DefinitionList/index.ts
    module.exports = r;
    /******/})();

==> react-ui-5.1.0.tgz: package/DefinitionList.js <==
/******/ (() => {
    // webpackBootstrap
    /******/ "use strict";
    /******/ // The require scope
    /******/    var e = {};
    /******/
    /************************************************************************/
    /******/ /* webpack/runtime/compat get default export */
    /******/    (() => {
        /******/ // getDefaultExport function for compatibility with non-harmony modules
        /******/ e.n = r => {
            /******/ var t = r && r.__esModule ? 
            /******/ () => r["default"]
            /******/ : () => r
            /******/;
            e.d(t, {
                a: t
            });
            /******/            return t;
            /******/        };
        /******/    })();
    /******/
    /******/ /* webpack/runtime/define property getters */
    /******/    (() => {
        /******/ // define getter functions for harmony exports
        /******/ e.d = (r, t) => {
            /******/ for (var n in t) {
                /******/ if (e.o(t, n) && !e.o(r, n)) {
                    /******/ Object.defineProperty(r, n, {
                        enumerable: true,
                        get: t[n]
                    });
                    /******/                }
                /******/            }
            /******/        };
        /******/    })();
    /******/
    /******/ /* webpack/runtime/hasOwnProperty shorthand */
    /******/    (() => {
        /******/ e.o = (e, r) => Object.prototype.hasOwnProperty.call(e, r)
        /******/;
    })();
    /******/
    /******/ /* webpack/runtime/make namespace object */
    /******/    (() => {
        /******/ // define __esModule on exports
        /******/ e.r = e => {
            /******/ if (typeof Symbol !== "undefined" && Symbol.toStringTag) {
                /******/ Object.defineProperty(e, Symbol.toStringTag, {
                    value: "Module"
                });
                /******/            }
            /******/            Object.defineProperty(e, "__esModule", {
                value: true
            });
            /******/        };
        /******/    })();
    /******/
    /************************************************************************/    var r = {};
    // ESM COMPAT FLAG
        e.r(r);
    // EXPORTS
        e.d(r, {
        Description: () => /* reexport */ h,
        Term: () => /* reexport */ P,
        default: () => /* reexport */ _
    });
    // CONCATENATED MODULE: external "react"
    const t = require("react");
    var n =  e.n(t);
    // CONCATENATED MODULE: external "prop-types"
    const i = require("prop-types");
    var o =  e.n(i);
    // CONCATENATED MODULE: ./src/DefinitionList/DefinitionListContext.tsx
    var a =  (0, t.createContext)({});
    // CONCATENATED MODULE: external "styled-components"
    const l = require("styled-components");
    var c =  e.n(l);
    // CONCATENATED MODULE: external "@splunk/themes"
    const s = require("@splunk/themes");
    // CONCATENATED MODULE: ./src/DefinitionList/DefinitionListStyles.ts
    var u = c().dl.withConfig({
        displayName: "DefinitionListStyles__Styled",
        componentId: "sc-1pqfrgm-0"
    })([ "", ";", ";" ], s.mixins.reset("block"), s.mixins.typography("body"));
    // CONCATENATED MODULE: ./src/DefinitionList/DescriptionStyles.ts
    var f = c().dd.withConfig({
        displayName: "DescriptionStyles__Styled",
        componentId: "sc-1jglixb-0"
    })([ "", ";", ";min-height:1.5em;padding-inline-start:", ";margin-inline-start:", ";" ], s.mixins.reset("block"), s.mixins.typography("body", {
        color: "active"
    }), s.variables.spacingSmall, (function(e) {
        var r = e.$termWidth;
        return r;
    }));
    // CONCATENATED MODULE: ./src/DefinitionList/Description.tsx
    function d() {
        return d = Object.assign ? Object.assign.bind() : function(e) {
            for (var r = 1; r < arguments.length; r++) {
                var t = arguments[r];
                for (var n in t) {
                    ({}).hasOwnProperty.call(t, n) && (e[n] = t[n]);
                }
            }
            return e;
        }, d.apply(null, arguments);
    }
    function p(e, r) {
        if (null == e) return {};
        var t, n, i = m(e, r);
        if (Object.getOwnPropertySymbols) {
            var o = Object.getOwnPropertySymbols(e);
            for (n = 0; n < o.length; n++) {
                t = o[n], r.includes(t) || {}.propertyIsEnumerable.call(e, t) && (i[t] = e[t]);
            }
        }
        return i;
    }
    function m(e, r) {
        if (null == e) return {};
        var t = {};
        for (var n in e) {
            if ({}.hasOwnProperty.call(e, n)) {
                if (r.includes(n)) continue;
                t[n] = e[n];
            }
        }
        return t;
    }
    var y = {
        children: o().node.isRequired,
        elementRef: o().oneOfType([ o().func, o().object ])
    };
    /**
 * Container component for a `DefinitionList` description.
 */    function v(e) {
        var r = e.children, i = e.elementRef, o = p(e, [ "children", "elementRef" ]);
        // @docs-props-type DescriptionPropsBase
                var l = (0, t.useContext)(a), c = l.termWidth;
        
        return n().createElement(f, d({
            "data-test": "description",
            ref: i,
            $termWidth: c
        }, o), r);
    }
    v.propTypes = y;
    /* harmony default export */    const h = v;
    // CONCATENATED MODULE: ./src/DefinitionList/TermStyles.ts
    var b = c().dt.withConfig({
        displayName: "TermStyles__Styled",
        componentId: "sc-1ao97j9-0"
    })([ "", ";", " float:left;overflow:hidden;overflow-x:hidden;white-space:nowrap;word-wrap:normal;", " width:", ";" ], s.mixins.reset("block"), s.mixins.typography("body", {
        color: "muted"
    }), (function(e) {
        var r = e.$separator;
        return r && r !== "none" && (0, l.css)([ "&::after{content:'", "';}" ], " ".concat(r.repeat(100)));
    }), (function(e) {
        var r = e.$termWidth;
        return r;
    }));
    // CONCATENATED MODULE: ./src/DefinitionList/Term.tsx
    function g() {
        return g = Object.assign ? Object.assign.bind() : function(e) {
            for (var r = 1; r < arguments.length; r++) {
                var t = arguments[r];
                for (var n in t) {
                    ({}).hasOwnProperty.call(t, n) && (e[n] = t[n]);
                }
            }
            return e;
        }, g.apply(null, arguments);
    }
    function O(e, r) {
        if (null == e) return {};
        var t, n, i = w(e, r);
        if (Object.getOwnPropertySymbols) {
            var o = Object.getOwnPropertySymbols(e);
            for (n = 0; n < o.length; n++) {
                t = o[n], r.includes(t) || {}.propertyIsEnumerable.call(e, t) && (i[t] = e[t]);
            }
        }
        return i;
    }
    function w(e, r) {
        if (null == e) return {};
        var t = {};
        for (var n in e) {
            if ({}.hasOwnProperty.call(e, n)) {
                if (r.includes(n)) continue;
                t[n] = e[n];
            }
        }
        return t;
    }
    var j = {
        children: o().node.isRequired,
        elementRef: o().oneOfType([ o().func, o().object ])
    };
    /**
 * Container component for a `DefinitionList` term.
 */    function S(e) {
        var r = e.children, i = e.elementRef, o = O(e, [ "children", "elementRef" ]);
        // @docs-props-type TermPropsBase
                var l = (0, t.useContext)(a), c = l.separatorCharacter, s = l.termWidth;
        
        return n().createElement(b, g({
            "data-test": "term",
            ref: i,
            $separator: c,
            $termWidth: s
        }, o), r);
    }
    S.propTypes = j;
    /* harmony default export */    const P = S;
    // CONCATENATED MODULE: ./src/DefinitionList/DefinitionList.tsx
    function x() {
        return x = Object.assign ? Object.assign.bind() : function(e) {
            for (var r = 1; r < arguments.length; r++) {
                var t = arguments[r];
                for (var n in t) {
                    ({}).hasOwnProperty.call(t, n) && (e[n] = t[n]);
                }
            }
            return e;
        }, x.apply(null, arguments);
    }
    function C(e, r) {
        if (null == e) return {};
        var t, n, i = R(e, r);
        if (Object.getOwnPropertySymbols) {
            var o = Object.getOwnPropertySymbols(e);
            for (n = 0; n < o.length; n++) {
                t = o[n], r.includes(t) || {}.propertyIsEnumerable.call(e, t) && (i[t] = e[t]);
            }
        }
        return i;
    }
    function R(e, r) {
        if (null == e) return {};
        var t = {};
        for (var n in e) {
            if ({}.hasOwnProperty.call(e, n)) {
                if (r.includes(n)) continue;
                t[n] = e[n];
            }
        }
        return t;
    }
    var T = {
        children: o().node,
        elementRef: o().oneOfType([ o().func, o().object ]),
        separatorCharacter: o().oneOf([ ".", o().string ]),
        termWidth: o().string
    };
    function W(e) {
        var r = e.children, t = e.elementRef, i = e.separatorCharacter, o = e.termWidth, l = o === void 0 ? "120px" : o, c = C(e, [ "children", "elementRef", "separatorCharacter", "termWidth" ]);
        // @docs-props-type DefinitionListPropsBase
        // eslint-disable-next-line react/jsx-no-constructed-context-values, react-perf/jsx-no-new-object-as-prop
                var s = {
            separatorCharacter: i,
            termWidth: l
        };
        
        return n().createElement(u, x({
            "data-test": "definition-list",
            ref: t
        }, c),  n().createElement(a.Provider, {
            value: s
        }, r));
    }
    W.propTypes = T;
    W.Description = h;
    W.Term = P;
    /* harmony default export */    const _ = W;
    // CONCATENATED MODULE: ./src/DefinitionList/index.ts
    module.exports = r;
    /******/})();
